@@ -7,8 +7,8 @@ See LICENSE for license details.
 """
 
 __author__ = "Samuel Stauffer <samuel@lefora.com>"
-__version__ = "1.4.2"
-__license__ = "Python"
+__version__ = "1.5.0"
+__license__ = "BSD"
 __all__ = ['Scrubber', 'SelectiveScriptScrubber', 'ScrubberWarning', 'UnapprovedJavascript', 'urlize']
 
 import re, string
@@ -83,11 +83,11 @@ class ScrubberWarning(object):
     pass
 
 class Scrubber(object):
-    def __init__(self, base_url=None):
-        self.autolink = bool(urlize)
-        self.nofollow = True
-        self.remove_comments = True
+    def __init__(self, base_url=None, autolink=True, nofollow=True, remove_comments=True):
         self.base_url = base_url
+        self.autolink = autolink and bool(urlize)
+        self.nofollow = nofollow
+        self.remove_comments = remove_comments
         self.allowed_tags = set((
             'a', 'abbr', 'acronym', 'b', 'bdo', 'big', 'blockquote', 'br',
             'center', 'cite', 'code',
@@ -107,7 +107,7 @@ class Scrubber(object):
             'face', 'size', # font tags
             'flashvars', # Not sure about flashvars - if any harm can come from it
             'classid', # FF needs the classid on object tags for flash
-            'name', 'value', 'quality', 'data', # for flash embed param tags, could limit to just param if this is harmful
+            'name', 'value', 'quality', 'data', 'scale', # for flash embed param tags, could limit to just param if this is harmful
         )) # Bad attributes: 'allowscriptaccess', 'xmlns', 'target'
         self.normalized_tag_replacements = {'b': 'strong', 'i': 'em'}
         self.warnings = []
